<?php
/**
 *  @package	PaidSystem
 *  @copyright	Copyright (C) 2010-2014 Juloa.com. All rights reserved.
 *  @license    GNU General Public License version 3, or later
 */

// Check to ensure this file is included in Joomla!
defined('_JEXEC') or die( 'Restricted access' );

use Joomla\Utilities\ArrayHelper as JArrayHelper;

JTable::addIncludePath(JPATH_ADMINISTRATOR.DS.'components'.DS.'com_paidsystem'.DS.'tables');
jimport('joomla.application.component.controller');

/**
 * Content Component Controller
 *
 * @package		Joomla
 * @subpackage	Content
 * @since 1.5
 */
class PaidsystemControllerTops extends TController
{
	function __construct($config= array()) {
		parent::__construct($config);
	
		// Apply, Save & New
		$this->registerTask('apply', 'save');
		$this->registerTask('save2new', 'save');
	}
	
	function init()
	{
		// Set the default view name from the Request
		$this->_view = $this->getView("admin",'html');

		// Push a model into the view
		$this->_model = $this->getModel( "top");
		try {
			$this->_view->setModel( $this->_model, true );
		} catch (Exception $e) {

		}
		
		$uri = JUri::getInstance();
		$baseurl = JURI::base()."../";

		$this->_view->baseurl = $baseurl;
		$this->_view->baseurl = $baseurl;
	}
	
	function display($cachable = false, $urlparams = false)
	{
		$this->canAccess();
		$this->init();
		$this->_view->setLayout("tops");
		$this->_view->display();
	}
	
	function edit()
	{
		$this->canAccess();
		$this->init();

		$this->_view->setLayout("edittop");
		$this->_view->display();
	}
	
	function add()
	{
		$this->canAccess();
		$this->init();

		$this->_view->setLayout("edittop");
		$this->_view->display();
	}
	
	function remove()
	{
		$this->canAccess();
		$app = JFactory::getApplication();
		
		$top = JTable::getInstance('top', 'PaidsystemTable');
		
		$input = JFactory::getApplication()->input;
		$ids = $input->get( 'tid', array(0), 'array');
		if (!is_array($ids)) {
			$table = array();
			$table[0] = $ids;
			$ids = $table;
		}
		foreach($ids as $id){
			$top->delete($id);
		}
		
		$app->enqueueMessage(\JText::_('PAIDSYSTEM_TOP_REMOVED'), 'message');
		$app->redirect( 'index.php?option=com_paidsystem&c=tops', 200 );
	}
	
	function unpublish()
	{
		$this->_changeState();
	}
	
	function publish()
	{
		$this->_changeState();
	}
	
	function save()
	{
		$this->canAccess();
		$app = JFactory::getApplication();
		
		$top = JTable::getInstance('top', 'PaidsystemTable');

		$input = JFactory::getApplication()->input;
		$post = $input->get->post->getArray();
        
        $post['params_acl'] = implode(',', $post['params_acl']);
        
		// bind it to the table
		if (!$top -> bind($post)) {
			throw new Exception($top->getError() );
		}
		
		// store it in the db
		if (!$top -> store()) {
			throw new Exception($top->getError() );
		}	
		
		$input = JFactory::getApplication()->input;
		$field_catsid = $input->get("field_catsid", array(), 'array' );
		$field_catsid = ",".implode(',', $field_catsid).",";
		if ($field_catsid != "")
		{
			$top->savecatsid($top->id,$field_catsid);
			
		}

		// Redirect the user and adjust session state based on the chosen task.
		$task = $input->get('task','','cmd');
		$app->enqueueMessage(\JText::_('PAIDSYSTEM_TOP_SAVED'), 'message');
		switch ($task)
		{
			case 'apply':
				$app->redirect( 'index.php?option=com_paidsystem&c=tops&task=edit&tid[]='.$top->id, 200);
				break;
		
			case 'save2new':
				$app->redirect( 'index.php?option=com_paidsystem&c=tops&task=add', 200);
				break;
		
			default:
				$app->redirect( 'index.php?option=com_paidsystem&c=tops', 200);
			break;
		}	
	}
	
	function _changeState()
	{
		$this->canAccess();
		$app = JFactory::getApplication();

		// Check for request forgeries
		JSession::checkToken() or jexit( 'Invalid Token' );

		$input = JFactory::getApplication()->input;
		$cid		= $input->get( 'tid', array(), 'array' );
		$publish	= ( $this->getTask() == 'publish' ? 1 : 0 );

		JArrayHelper::toInteger($cid);

		if (count( $cid ) < 1)
		{
			$action = $publish ? 'publish' : 'unpublish';
			throw new Exception( JText::_( 'Select an item to' .$action, true ) );
		}
		
		$model = $this->getModel( "top");
		$model->changeState("#__paidsystem_top","id","published",$publish,$cid);
		
		$cache = JFactory::getCache('com_adsmanager');
		$cache->clean();

		$app->redirect( 'index.php?option=com_paidsystem&c=tops', 200 );
	}	
	
	function orderdown()
	{
		$this->_changeOrder(1);
	}
	
	function orderup()
	{
		$this->_changeOrder(-1);
	}
	
	function _changeOrder($inc)
	{
		$this->canAccess();
		$app = JFactory::getApplication();
		
		$input = JFactory::getApplication()->input;
		$cid		= $input->get( 'tid', array(), 'array' );
		
		if ($cid[0]) {
			$id = $cid[0];
			$row = JTable::getInstance('top', 'PaidsystemTable');
			$row->load( $id );
			$row->move( $inc, "1" );
		}

		$app->redirect( 'index.php?option=com_paidsystem&c=tops', 200 );
	}
	
	function saveorder()
	{
		$this->canAccess();
		$app = JFactory::getApplication();

		// Check for request forgeries
		JSession::checkToken() or jexit( 'Invalid Token' );
	
		$input = JFactory::getApplication()->input;
		// Initialize variables
		$cid 	= $input->get('tid', array(0), 'array');
		JArrayHelper::toInteger($cid, array(0));
		$total		= count( $cid );
		$order 		= $input->get( 'order', array(0), 'array' );
		JArrayHelper::toInteger($order, array(0));
	
		$row = JTable::getInstance('top', 'PaidsystemTable');

		// update ordering values
		for( $i=0; $i < $total; $i++ ) {
			$row->load( (int) $cid[$i] );
			if ($row->ordering != $order[$i]) {
				$row->ordering = $order[$i];
				if (!$row->store()) {
					throw new Exception( $row->getError() );
				}
			}
		}
		
		// Check if i'm using an AJAX call, in this case there is no need to redirect
		$format = $input->get('format','', 'String');
		$status="";
		if ($format == 'json')
		{
			echo json_encode($status);
		
			return;
		}

		$app->redirect( 'index.php?option=com_paidsystem&c=tops', 200 );
	}

	private function canAccess() {
		$app = JFactory::getApplication();

		//check if the user can access the categories
		$user = JFactory::getUser();
		if(!$user->authorise('paidsystem.accesstop','com_paidsystem')) {
			$app->enqueueMessage(\JText::_('JERROR_ALERTNOAUTHOR'), 'error');
			$app->redirect('index.php', 200);
		}

		return true;
	}
}
